# citation-title

![Github CI](https://github.com/justmars/citation-title/actions/workflows/main.yml/badge.svg)

## Development

See [documentation](https://justmars.github.io/citation-title).

1. Run `poetry install`
2. Run `poetry shell`
3. Run `pytest`
